@@ -11,6 +11,10 @@ class UsersStore(metaclass=ABCMeta):
     def fetch_notifications(self, items_count):
         pass
 
+    @abstractmethod
+    def fetch_notification_by_id(self, id):
+        pass
+
     @abstractmethod
     def insert_notification(self, user_id, user_name, user_email, expression_to_evaluate, check_every_seconds,
                             check_times, is_active, channel_type, fields_to_send, source_id, operation):
@@ -22,6 +26,11 @@ class UsersStore(metaclass=ABCMeta):
                             check_times, is_active, channel_type, fields_to_send, source_id, operation):
         pass
 
+    @abstractmethod
+    def fetch_user_settings_by_id(self, id):
+        pass
+
+
     @abstractmethod
     def update_user_settings(self, user_id, preferred_currency):
         pass
@@ -30,6 +39,11 @@ class UsersStore(metaclass=ABCMeta):
     def insert_user_settings(self, user_id, preferred_currency):
         pass
 
+    @abstractmethod
+    def fetch_user_channel_by_id(self, id):
+        pass
+
+
     @abstractmethod
     def insert_user_channel(self, user_id, channel_type, chat_id):
         pass
